@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from outflow.core.pipeline import context
+from outflow.core.tasks.io_checker import IOChecker
 from outflow.core.logging import logger
 from outflow.core.tasks import TaskManager
 from outflow.core.types import Skipped
@@ -11,15 +11,14 @@ class Backend:
         self.name = "default"
 
     def run(self, *, task_list):
-        logger.debug(
-            f"Run pipeline with backend '{self}' and with pipeline context '{context}'"
-        )
 
         task_manager = TaskManager()
 
         for task in task_list:
-            task.workflow.set_context(context)
-            task_manager.compute(task.workflow)
+            task_manager.compute(
+                task.workflow
+            )  # todo call on top level workflow instead
+            # but still return results of task_list, if list is not none
 
         execution_return = [task_manager.results.resolve(task.id) for task in task_list]
         filter_results = False  # TODO parametrize outside
@@ -33,5 +32,11 @@ class Backend:
         else:
             return execution_return
 
+    def check_task_io(self, task_list):
+        logger.debug("Checking tasks input and output coherence")
+        io_checker = IOChecker()
+        for task in task_list:
+            io_checker.compute(task.workflow)
+
     def clean(self):
         pass
