@@ -2,6 +2,10 @@
 from .lazy_object_proxy import LazyObjectProxy
 
 
+def recreate_lazy_object(factory):
+    return SerializableProxy(factory=factory)
+
+
 class SerializableProxy(LazyObjectProxy):
     def __getstate__(self):
         return {}
@@ -14,3 +18,6 @@ class SerializableProxy(LazyObjectProxy):
 
     def setstate(self, state):
         self.__wrapped__.__setstate__(state)
+
+    def __reduce_ex__(self, protocol):
+        return recreate_lazy_object, (self.__factory__,)
