@@ -10,7 +10,7 @@ from pprint import pformat
 
 import jinja2
 import outflow
-from outflow.core.command import argument
+from outflow.core.commands import argument
 from outflow.core.logging import logger
 
 from .management import Management
@@ -209,3 +209,5 @@ def Plugin(name, plugin_dir, namespace, cython):
         raise NotImplementedError("Plugins without namespace are not yet supported")
 
     create_from_template("plugin", name, plugin_dir, namespace)
+
+    logger.info(f"Plugin '{name}' successfully created")
