@@ -1,3 +1,3 @@
 # -*- coding: utf-8 -*-
-from .map_task import MapTask  # noqa: F401
+from .map_task import ParallelMapTask  # noqa: F401
 from .parallel_task import ParallelTask  # noqa: F401
